@@ -23,6 +23,9 @@
 #include <QtPositioning/qgeosatelliteinfosource.h>
 #include <QtPositioning/qgeoshape.h>
 #include <QtPositioning/qnmeapositioninfosource.h>
+#include <QtPositioning/qnmeasatelliteinfosource.h>
+
+QT_BEGIN_NAMESPACE
 class QGeoAddress;
 class QGeoAreaMonitorInfo;
 class QGeoCircle;
@@ -31,6 +34,7 @@ class QGeoPath;
 class QGeoPolygon;
 class QGeoPositionInfoSourceFactory;
 class QGeoRectangle;
+QT_END_NAMESPACE
 
 // Type indices
 enum [[deprecated]] : int {
@@ -64,7 +68,10 @@ enum [[deprecated]] : int {
     SBK_QGEOSHAPE_IDX                                        = 52,
     SBK_QNMEAPOSITIONINFOSOURCE_UPDATEMODE_IDX               = 58,
     SBK_QNMEAPOSITIONINFOSOURCE_IDX                          = 56,
-    SBK_QTPOSITIONING_IDX_COUNT                              = 60,
+    SBK_QNMEASATELLITEINFOSOURCE_UPDATEMODE_IDX              = 64,
+    SBK_QNMEASATELLITEINFOSOURCE_SATELLITEINFOPARSESTATUS_IDX = 62,
+    SBK_QNMEASATELLITEINFOSOURCE_IDX                         = 60,
+    SBK_QTPOSITIONING_IDX_COUNT                              = 66,
 };
 
 // Type indices
@@ -99,12 +106,18 @@ enum : int {
     SBK_QGeoShape_IDX                                        = 26,
     SBK_QNmeaPositionInfoSource_UpdateMode_IDX               = 29,
     SBK_QNmeaPositionInfoSource_IDX                          = 28,
-    SBK_QtPositioning_IDX_COUNT                              = 30,
+    SBK_QNmeaSatelliteInfoSource_UpdateMode_IDX              = 32,
+    SBK_QNmeaSatelliteInfoSource_SatelliteInfoParseStatus_IDX = 31,
+    SBK_QNmeaSatelliteInfoSource_IDX                         = 30,
+    SBK_QtPositioning_IDX_COUNT                              = 33,
 };
 
 // This variable stores all Python types exported by this module.
 extern Shiboken::Module::TypeInitStruct *SbkPySide6_QtPositioningTypeStructs;
 
+// This variable stores all Python types exported by this module in a backwards compatible way with identical indexing.
+[[deprecated]] extern PyTypeObject **SbkPySide6_QtPositioningTypes;
+
 // This variable stores the Python module object exported by this module.
 extern PyObject *SbkPySide6_QtPositioningModuleObject;
 
@@ -114,15 +127,13 @@ extern SbkConverter **SbkPySide6_QtPositioningTypeConverters;
 // Converter indices
 enum [[deprecated]] : int {
     SBK_QTPOSITIONING_QLIST_INT_IDX                          = 0, // QList<int>
-    SBK_QTPOSITIONING_QLIST_QGEOCOORDINATE_IDX               = 2, // QList<QGeoCoordinate>
-    SBK_QTPOSITIONING_QMAP_QSTRING_QVARIANT_IDX              = 4, // QMap<QString,QVariant>
-    SBK_QTPOSITIONING_QLIST_QVARIANT_IDX                     = 6, // QList<QVariant>
-    SBK_QTPOSITIONING_QLIST_QOBJECTPTR_IDX                   = 8, // QList<QObject*>
-    SBK_QTPOSITIONING_QLIST_QBYTEARRAY_IDX                   = 10, // QList<QByteArray>
-    SBK_QTPOSITIONING_QLIST_QGEOSATELLITEINFO_IDX            = 12, // QList<QGeoSatelliteInfo>
-    SBK_QTPOSITIONING_QLIST_QGEOAREAMONITORINFO_IDX          = 14, // QList<QGeoAreaMonitorInfo>
-    SBK_QTPOSITIONING_QLIST_QSTRING_IDX                      = 16, // QList<QString>
-    SBK_QTPOSITIONING_CONVERTERS_IDX_COUNT                   = 18,
+    SBK_QTPOSITIONING_QLIST_QGEOCOORDINATE_IDX               = 1, // QList<QGeoCoordinate>
+    SBK_QTPOSITIONING_QMAP_QSTRING_QVARIANT_IDX              = 2, // QMap<QString,QVariant>
+    SBK_QTPOSITIONING_QLIST_QVARIANT_IDX                     = 3, // QList<QVariant>
+    SBK_QTPOSITIONING_QLIST_QGEOSATELLITEINFO_IDX            = 4, // QList<QGeoSatelliteInfo>
+    SBK_QTPOSITIONING_QLIST_QGEOAREAMONITORINFO_IDX          = 5, // QList<QGeoAreaMonitorInfo>
+    SBK_QTPOSITIONING_QLIST_QSTRING_IDX                      = 6, // QList<QString>
+    SBK_QTPOSITIONING_CONVERTERS_IDX_COUNT                   = 7,
 };
 
 // Converter indices
@@ -131,12 +142,10 @@ enum : int {
     SBK_QtPositioning_QList_QGeoCoordinate_IDX               = 1, // QList<QGeoCoordinate>
     SBK_QtPositioning_QMap_QString_QVariant_IDX              = 2, // QMap<QString,QVariant>
     SBK_QtPositioning_QList_QVariant_IDX                     = 3, // QList<QVariant>
-    SBK_QtPositioning_QList_QObjectPTR_IDX                   = 4, // QList<QObject*>
-    SBK_QtPositioning_QList_QByteArray_IDX                   = 5, // QList<QByteArray>
-    SBK_QtPositioning_QList_QGeoSatelliteInfo_IDX            = 6, // QList<QGeoSatelliteInfo>
-    SBK_QtPositioning_QList_QGeoAreaMonitorInfo_IDX          = 7, // QList<QGeoAreaMonitorInfo>
-    SBK_QtPositioning_QList_QString_IDX                      = 8, // QList<QString>
-    SBK_QtPositioning_CONVERTERS_IDX_COUNT                   = 9,
+    SBK_QtPositioning_QList_QGeoSatelliteInfo_IDX            = 4, // QList<QGeoSatelliteInfo>
+    SBK_QtPositioning_QList_QGeoAreaMonitorInfo_IDX          = 5, // QList<QGeoAreaMonitorInfo>
+    SBK_QtPositioning_QList_QString_IDX                      = 6, // QList<QString>
+    SBK_QtPositioning_CONVERTERS_IDX_COUNT                   = 7,
 };
 // Macros for type check
 
@@ -176,6 +185,9 @@ template<> inline PyTypeObject *SbkType< ::QGeoShape::ShapeType >() { return Shi
 template<> inline PyTypeObject *SbkType< ::QGeoShape >() { return Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QGeoShape_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNmeaPositionInfoSource::UpdateMode >() { return Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_UpdateMode_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNmeaPositionInfoSource >() { return Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaPositionInfoSource_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QNmeaSatelliteInfoSource::UpdateMode >() { return Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaSatelliteInfoSource_UpdateMode_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QNmeaSatelliteInfoSource::SatelliteInfoParseStatus >() { return Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaSatelliteInfoSource_SatelliteInfoParseStatus_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QNmeaSatelliteInfoSource >() { return Shiboken::Module::get(SbkPySide6_QtPositioningTypeStructs[SBK_QNmeaSatelliteInfoSource_IDX]); }
 
 } // namespace Shiboken
 
