@@ -18,7 +18,10 @@
 // Bound library includes
 #include <QtSvg/qsvggenerator.h>
 #include <QtSvg/qtsvgglobal.h>
+
+QT_BEGIN_NAMESPACE
 class QSvgRenderer;
+QT_END_NAMESPACE
 
 // Type indices
 enum [[deprecated]] : int {
@@ -45,6 +48,9 @@ enum : int {
 // This variable stores all Python types exported by this module.
 extern Shiboken::Module::TypeInitStruct *SbkPySide6_QtSvgTypeStructs;
 
+// This variable stores all Python types exported by this module in a backwards compatible way with identical indexing.
+[[deprecated]] extern PyTypeObject **SbkPySide6_QtSvgTypes;
+
 // This variable stores the Python module object exported by this module.
 extern PyObject *SbkPySide6_QtSvgModuleObject;
 
@@ -54,23 +60,19 @@ extern SbkConverter **SbkPySide6_QtSvgTypeConverters;
 // Converter indices
 enum [[deprecated]] : int {
     SBK_QTSVG_QLIST_INT_IDX                                  = 0, // QList<int>
-    SBK_QTSVG_QLIST_QOBJECTPTR_IDX                           = 2, // QList<QObject*>
-    SBK_QTSVG_QLIST_QBYTEARRAY_IDX                           = 4, // QList<QByteArray>
-    SBK_QTSVG_QLIST_QVARIANT_IDX                             = 6, // QList<QVariant>
-    SBK_QTSVG_QLIST_QSTRING_IDX                              = 8, // QList<QString>
-    SBK_QTSVG_QMAP_QSTRING_QVARIANT_IDX                      = 10, // QMap<QString,QVariant>
-    SBK_QTSVG_CONVERTERS_IDX_COUNT                           = 12,
+    SBK_QTSVG_QLIST_QVARIANT_IDX                             = 1, // QList<QVariant>
+    SBK_QTSVG_QLIST_QSTRING_IDX                              = 2, // QList<QString>
+    SBK_QTSVG_QMAP_QSTRING_QVARIANT_IDX                      = 3, // QMap<QString,QVariant>
+    SBK_QTSVG_CONVERTERS_IDX_COUNT                           = 4,
 };
 
 // Converter indices
 enum : int {
     SBK_QtSvg_QList_int_IDX                                  = 0, // QList<int>
-    SBK_QtSvg_QList_QObjectPTR_IDX                           = 1, // QList<QObject*>
-    SBK_QtSvg_QList_QByteArray_IDX                           = 2, // QList<QByteArray>
-    SBK_QtSvg_QList_QVariant_IDX                             = 3, // QList<QVariant>
-    SBK_QtSvg_QList_QString_IDX                              = 4, // QList<QString>
-    SBK_QtSvg_QMap_QString_QVariant_IDX                      = 5, // QMap<QString,QVariant>
-    SBK_QtSvg_CONVERTERS_IDX_COUNT                           = 6,
+    SBK_QtSvg_QList_QVariant_IDX                             = 1, // QList<QVariant>
+    SBK_QtSvg_QList_QString_IDX                              = 2, // QList<QString>
+    SBK_QtSvg_QMap_QString_QVariant_IDX                      = 3, // QMap<QString,QVariant>
+    SBK_QtSvg_CONVERTERS_IDX_COUNT                           = 4,
 };
 // Macros for type check
 
